@@ -32,6 +32,15 @@ from six import unichr
 # use system fonts
 SYSTEM_FONTS = False
 
+# MD5 Hashes for font files bundled with qtawesome:
+MD5_HASHES = {
+    'fontawesome4.7-webfont.ttf': 'b06871f281fee6b241d60582ae9369b9',
+    'fontawesome5-regular-webfont.ttf': '6a745dc6a0871f350b0219f5a2678838',
+    'fontawesome5-solid-webfont.ttf': 'ab3b872bcb10de4ef62852b10e9ef103',
+    'fontawesome5-brands-webfont.ttf': 'd6ac6c968cff1abcbf5d548828b9f6c6',
+    'elusiveicons-webfont.ttf': '207966b04c032d5b873fd595a211582e',
+    'materialdesignicons-webfont.ttf': '023db9122f66b7d693bc52bcdf09e6b3',
+}
 
 _default_options = {
     'color': QColor(50, 50, 50),
@@ -176,6 +185,7 @@ class IconicFont(QObject):
         self.painters = {}
         self.fontname = {}
         self.charmap = {}
+        self.icon_cache = {}
         for fargs in args:
             self.load_font(*fargs)
 
@@ -227,19 +237,7 @@ class IconicFont(QObject):
 
             # Verify that vendorized fonts are not corrupt
             if not SYSTEM_FONTS:
-                md5_hashes = {'fontawesome4.7-webfont.ttf':
-                              'b06871f281fee6b241d60582ae9369b9',
-                              'fontawesome5-regular-webfont.ttf':
-                              '73fe7f1effbf382f499831a0a9f18626',
-                              'fontawesome5-solid-webfont.ttf':
-                              '0079a0ab6bec4da7d6e16f2a2e87cd71',
-                              'fontawesome5-brands-webfont.ttf':
-                              '947b9537bc0fecc8130d48eb753495a1',
-                              'elusiveicons-webfont.ttf':
-                              '207966b04c032d5b873fd595a211582e',
-                              'materialdesignicons-webfont.ttf':
-                              '64b96825d49e070ea87c7100f2db3f46'}
-                ttf_hash = md5_hashes.get(ttf_filename, None)
+                ttf_hash = MD5_HASHES.get(ttf_filename, None)
                 if ttf_hash is not None:
                     hasher = hashlib.md5()
                     with open(os.path.join(directory, ttf_filename),
@@ -253,29 +251,32 @@ class IconicFont(QObject):
 
     def icon(self, *names, **kwargs):
         """Return a QIcon object corresponding to the provided icon name."""
-        options_list = kwargs.pop('options', [{}] * len(names))
-        general_options = kwargs
+        cache_key = '{}{}'.format(names,kwargs)
+        if cache_key not in self.icon_cache:
+            options_list = kwargs.pop('options', [{}] * len(names))
+            general_options = kwargs
 
-        if len(options_list) != len(names):
-            error = '"options" must be a list of size {0}'.format(len(names))
-            raise Exception(error)
+            if len(options_list) != len(names):
+                error = '"options" must be a list of size {0}'.format(len(names))
+                raise Exception(error)
 
-        if QApplication.instance() is not None:
-            parsed_options = []
-            for i in range(len(options_list)):
-                specific_options = options_list[i]
-                parsed_options.append(self._parse_options(specific_options,
-                                                          general_options,
-                                                          names[i]))
+            if QApplication.instance() is not None:
+                parsed_options = []
+                for i in range(len(options_list)):
+                    specific_options = options_list[i]
+                    parsed_options.append(self._parse_options(specific_options,
+                                                              general_options,
+                                                              names[i]))
 
-            # Process high level API
-            api_options = parsed_options
+                # Process high level API
+                api_options = parsed_options
 
-            return self._icon_by_painter(self.painter, api_options)
-        else:
-            warnings.warn("You need to have a running "
-                          "QApplication to use QtAwesome!")
-            return QIcon()
+                self.icon_cache[cache_key] = self._icon_by_painter(self.painter, api_options)
+            else:
+                warnings.warn("You need to have a running "
+                              "QApplication to use QtAwesome!")
+                return QIcon()
+        return self.icon_cache[cache_key]
 
     def _parse_options(self, specific_options, general_options, name):
         options = dict(_default_options, **general_options)
